@@ -29,16 +29,16 @@
 // libkscreensaver interface
 extern "C"
 {
-    const char *kss_applicationName = "klorenz.kss";
-    const char *kss_description = I18N_NOOP( "KLorenz" );
-    const char *kss_version = "2.2.0";
+    KDE_EXPORT const char *kss_applicationName = "klorenz.kss";
+    KDE_EXPORT const char *kss_description = I18N_NOOP( "KLorenz" );
+    KDE_EXPORT const char *kss_version = "2.2.0";
 
-    KScreenSaver *kss_create( WId id )
+    KDE_EXPORT KScreenSaver *kss_create( WId id )
     {
         return new KLorenzSaver( id );
     }
 
-    QDialog *kss_setup()
+    KDE_EXPORT QDialog *kss_setup()
     {
         return new KLorenzSetup();
     }
