@@ -48,7 +48,7 @@ private slots:
 	void slotSpeed( int );
 	void slotWarp( int );
 	void slotOk();
-	void slotAbout();
+	void slotHelp();
 
 private:
 	QWidget *preview;
