@@ -7,10 +7,8 @@
 #define __SWARM_H__
 
 #include <qtimer.h>
-#include <qptrlist.h>
-#include <qdialog.h>
-#include <qlineedit.h>
-#include <krandomsequence.h>
+
+#include <kdialogbase.h>
 #include "saver.h"
 
 
@@ -39,7 +37,7 @@ protected:
 	int			maxLevels;
 };
 
-class kSwarmSetup : public QDialog
+class kSwarmSetup : public KDialogBase
 {
 	Q_OBJECT
 public:
@@ -51,8 +49,9 @@ protected:
 private slots:
 	void slotSpeed( int );
 	void slotLevels( int );
-	void slotOkPressed();
-	void slotAbout();
+
+	void slotOk();
+	void slotHelp();
 
 private:
 	QWidget *preview;
