@@ -805,7 +805,7 @@ void smoothblendClient::addButtons(QBoxLayout *layout, const QString& s, int but
                 break;
 
             case 'L': // Shade button
-                if ((!button[ButtonShade && isShadeable()])) {
+                if ((!button[ButtonShade]) && isShadeable()) {
                     if ( isSetShade()) {
                         tip = i18n("Unshade");
                     } else {
