@@ -427,6 +427,9 @@ bool SystemClient::eventFilter( QObject* o, QEvent* e )
     case QEvent::MouseButtonPress:
        processMousePressEvent(static_cast< QMouseEvent* >( e ) );
        return true;
+    case QEvent::Wheel:
+       wheelEvent( static_cast< QWheelEvent* >( e ));
+       return true;
     default:
         break;
     }
@@ -608,6 +611,12 @@ void SystemClient::mouseDoubleClickEvent( QMouseEvent * e )
       titlebarDblClickOperation();
 }
 
+void SystemClient::wheelEvent( QWheelEvent *e )
+{
+    if (isSetShade() || QRect( 0, 0, width(), titlebar->geometry().height() ).contains( e->pos() ) )
+        titlebarMouseWheelOperation( e->delta());
+}
+
 void SystemClient::maximizeChange()
 {
     unsigned char *minmax_bits;
